==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/guardduty_detector/GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings.java <==
package com.hashicorp.cdktf.providers.aws.guardduty_detector;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:54.157Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.guarddutyDetector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings")
@software.amazon.jsii.Jsii.Proxy(GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings extends software.amazon.jsii.JsiiSerializable {

    /**
     * ebs_volumes block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#ebs_volumes GuarddutyDetector#ebs_volumes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes getEbsVolumes();

    /**
     * @return a {@link Builder} of {@link GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings> {
        com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes ebsVolumes;

        /**
         * Sets the value of {@link GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings#getEbsVolumes}
         * @param ebsVolumes ebs_volumes block. This parameter is required.
         *                   Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#ebs_volumes GuarddutyDetector#ebs_volumes}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ebsVolumes(com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes ebsVolumes) {
            this.ebsVolumes = ebsVolumes;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings {
        private final com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes ebsVolumes;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.ebsVolumes = software.amazon.jsii.Kernel.get(this, "ebsVolumes", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.ebsVolumes = java.util.Objects.requireNonNull(builder.ebsVolumes, "ebsVolumes is required");
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes getEbsVolumes() {
            return this.ebsVolumes;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("ebsVolumes", om.valueToTree(this.getEbsVolumes()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.guarddutyDetector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings.Jsii$Proxy that = (GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings.Jsii$Proxy) o;

            return this.ebsVolumes.equals(that.ebsVolumes);
        }

        @Override
        public final int hashCode() {
            int result = this.ebsVolumes.hashCode();
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/guardduty_detector/GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings.java <==
package com.hashicorp.cdktf.providers.aws.guardduty_detector;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:10.009Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.guarddutyDetector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings")
@software.amazon.jsii.Jsii.Proxy(GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings extends software.amazon.jsii.JsiiSerializable {

    /**
     * ebs_volumes block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/guardduty_detector#ebs_volumes GuarddutyDetector#ebs_volumes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes getEbsVolumes();

    /**
     * @return a {@link Builder} of {@link GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings> {
        com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes ebsVolumes;

        /**
         * Sets the value of {@link GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings#getEbsVolumes}
         * @param ebsVolumes ebs_volumes block. This parameter is required.
         *                   Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/guardduty_detector#ebs_volumes GuarddutyDetector#ebs_volumes}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ebsVolumes(com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes ebsVolumes) {
            this.ebsVolumes = ebsVolumes;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings {
        private final com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes ebsVolumes;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.ebsVolumes = software.amazon.jsii.Kernel.get(this, "ebsVolumes", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.ebsVolumes = java.util.Objects.requireNonNull(builder.ebsVolumes, "ebsVolumes is required");
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.guardduty_detector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes getEbsVolumes() {
            return this.ebsVolumes;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("ebsVolumes", om.valueToTree(this.getEbsVolumes()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.guarddutyDetector.GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings.Jsii$Proxy that = (GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings.Jsii$Proxy) o;

            return this.ebsVolumes.equals(that.ebsVolumes);
        }

        @Override
        public final int hashCode() {
            int result = this.ebsVolumes.hashCode();
            return result;
        }
    }
}
